@@ -188,6 +188,7 @@
         anonymous_parameters,
         array_into_iter,
         asm_sub_register,
+        bad_asm_style,
         bare_trait_objects,
         bindings_with_variant_name,
         box_pointers,
@@ -201,7 +202,9 @@
         dead_code,
         deprecated,
         deprecated_in_future,
+        deref_nullptr,
         drop_bounds,
+        dyn_drop,
         elided_lifetimes_in_paths,
         ellipsis_inclusive_range_patterns,
         explicit_outlives_requirements,
@@ -218,6 +221,7 @@
         invalid_value,
         irrefutable_let_patterns,
         keyword_idents,
+        large_assignments,
         late_bound_lifetime_arguments,
         legacy_derive_helpers,
         macro_use_extern_crate,
@@ -231,6 +235,7 @@
         no_mangle_generic_items,
         non_ascii_idents,
         non_camel_case_types,
+        non_fmt_panics,
         non_shorthand_field_patterns,
         non_snake_case,
         non_upper_case_globals,
@@ -244,6 +249,10 @@
         proc_macro_derive_resolution_fallback,
         redundant_semicolons,
         renamed_and_removed_lints,
+        rust_2021_incompatible_closure_captures,
+        rust_2021_incompatible_or_patterns,
+        rust_2021_prefixes_incompatible_syntax,
+        rust_2021_prelude_collisions,
         semicolon_in_expressions_from_macros,
         single_use_lifetimes,
         stable_features,
@@ -266,6 +275,7 @@
         unsafe_op_in_unsafe_fn,
         unstable_features,
         unstable_name_collisions,
+        unsupported_calling_conventions,
         unsupported_naked_functions,
         unused_allocation,
         unused_assignments,
@@ -290,7 +300,7 @@
         unused_variables,
         variant_size_differences,
         where_clauses_object_safety,
-        while_true
+        while_true,
     )
 )]
 // nightly only lints
